ApiSellon class

Constructors

ApiSellon(BuildContext _context)

Properties

context → BuildContext
no setter
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>
no setter
isDataAsList ↔ bool?
getter/setter pair
isDataAsString ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeoutDuration ↔ Duration?
getter/setter pair

Methods

clearPaginator() → Paginator?
createPaginator() → Paginator?
execute(String _method, SellonMethod sellonMethod, Parameter _parameter, OnSuccessListener _onSuccessListener, {bool? isShowMessage, bool? encrytion}) → dynamic
executeFuture(String _method, SellonMethod sellonMethod, Parameter _parameter, OnSuccessListener _onSuccessListener, {bool? encryption}) → Future<String?>
getMimeType(String path) → String
getPaginator() → Paginator?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCompleteListener(OnCompleteListener _onCompleteListener) → ApiSellon
setErrorListener(OnErrorListener _onErrorListener) → ApiSellon
setExceptionListener(OnExceptionListener _onExceptionListener) → ApiSellon
setIsShowDialog(bool value) → ApiSellon
setSuccessListener(OnSuccessListener _onSuccessListener) → ApiSellon
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

createDefaultParams(OnCreateDefaultParamsListener callback) → dynamic
createParams() → Parameter