AppSettings class

Constructors

AppSettings()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openLocation() → Future<String>
toString() → String
A string representation of this object.
inherited
turnOFFGps() → Future<bool>
turnONGps() → Future<bool>

Operators

operator ==(Object other) → bool
The equality operator.
inherited