DefaultImageView class

Inheritance

Constructors

DefaultImageView({double? width, double? height, String? imageUrl, BoxFit? boxFit, bool? isKategory, double? circle, double? paddingWidth, bool? isProfile, bool? isDetail, Color? colorbackground, bool? isGif, String? video, String? path, EdgeInsets? margin, bool? cover, double? fullSize})

Properties

boxFit → BoxFit?
final
circle → double?
final
colorbackground → Color?
final
cover → bool?
final
fullSize ↔ double?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
imageUrl → String?
final
isDetail → bool?
final
isGif → bool?
final
isKategory → bool?
final
isProfile → bool?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin → EdgeInsets?
final
paddingWidth → double?
final
path → String?
final
persen ↔ int?
getter/setter pair
persen2 ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
video → String?
final
width → double?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
fotoBuild(BuildContext context) → Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited