ThumbnailRequest class

Constructors

ThumbnailRequest({String? video, String? thumbnailPath, ImageFormat? imageFormat, int? maxHeight, int? maxWidth, int? timeMs, int? quality})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
imageFormat → ImageFormat?
final
maxHeight → int?
final
maxWidth → int?
final
quality → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnailPath → String?
final
timeMs → int?
final
video → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited