ThumbnailResult class

Constructors

ThumbnailResult({Image? image, int? dataSize, int? height, int? width})
const

Properties

dataSize → int?
final
hashCode → int
The hash code for this object.
no setterinherited
height → int?
final
image → Image?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited