DefaultTextField class

Inheritance

Constructors

DefaultTextField({Key? key, bool? isBank, String? hint, String? label, String? errorMessage, String? obscuringCharacter = '●', bool? enabled = true, dynamic onTap()?, TextInputAction? action, TextInputType? keyboardType, int? maxLines = 1, int? minLines = 1, bool? isQty = false, EdgeInsets? padding, @required TextEditingController? controller, EdgeInsets? margin = const EdgeInsets.all(0), bool? obscureText, TextInputType? textInputType = TextInputType.text, TextInputAction? textInputAction = TextInputAction.done, dynamic onFieldSubmitted(String)?, dynamic onChanged(String)?, Widget? suffix, String? assets, FocusNode? node, BorderRadius? borderRadius, Border? border, Color? colorsText, bool? enableTextView, String? condition, Color? colorHint, bool? isPassword, String? suffixIcon, Icons? suffixIcons, String? customSuffixIcon, bool? isSearch, bool? isMessage, bool? isEdit, bool? counterText, int? maxLenght = 3, Color? focusedBorderColor, TextAlign? textAlign, dynamic onEditingFinished()?, bool? isCurrency, bool? isWeight, Color? colorBackground, bool? autoFocus, dynamic onTapSuffix()?, bool? isEnableBorder, bool? isHideHint, TextStyle? hintStyle, TextStyle? labelStyle, Color? cursorColor, Color? titleColorActive, @required FocusNode? focusNode})
const

Properties

action → TextInputAction?
final
assets → String?
final
autoFocus → bool?
final
border → Border?
final
borderRadius → BorderRadius?
final
colorBackground → Color?
final
colorHint → Color?
final
colorsText → Color?
final
condition → String?
final
controller → TextEditingController?
final
counterText → bool?
final
cursorColor → Color?
final
customSuffixIcon → String?
final
enabled → bool?
final
enableTextView → bool?
final
errorMessage → String?
final
focusedBorderColor → Color?
final
focusNode → FocusNode?
final
hashCode → int
The hash code for this object.
no setterinherited
hint → String?
final
hintStyle → TextStyle?
final
isBank → bool?
final
isCurrency → bool?
final
isEdit → bool?
final
isEnableBorder → bool?
final
isHideHint → bool?
final
isMessage → bool?
final
isPassword → bool?
final
isQty → bool?
final
isSearch → bool?
final
isWeight → bool?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType → TextInputType?
final
label → String?
final
labelStyle → TextStyle?
final
margin → EdgeInsets?
final
maxLenght → int?
final
maxLines → int?
final
minLines → int?
final
node → FocusNode?
final
obscureText → bool?
final
obscuringCharacter → String?
final
onChanged → dynamic Function(String)?
final
onEditingFinished → dynamic Function()?
final
onFieldSubmitted → dynamic Function(String)?
final
onTap → dynamic Function()?
final
onTapSuffix → dynamic Function()?
final
padding → EdgeInsets?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suffix → Widget?
final
suffixIcon → String?
final
suffixIcons → Icons?
final
textAlign → TextAlign?
final
textInputAction → TextInputAction?
final
textInputType → TextInputType?
final
titleColorActive → Color?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _defaultTextField
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited