DefaultText class

Inheritance

Constructors

DefaultText({String? textLabel, dynamic iconLeft, Color? colorsText, double? sizeText, Color? colorbackground, double? width, double? height, Alignment? alignment, BorderRadius? borderRadius, FontWeight? fontWeight, EdgeInsets? padding, EdgeInsets? margin, FontStyle? fontStyle, TextOverflow? textOverflow, TextAlign? textAlign, Border? border, List<BoxShadow>? boxShadow, int? maxLines, bool? isGradient, String? fonts, String? userTagID, TextDecoration? textDe, String? userTag, bool? isHpyerlink, GlobalKey<State<StatefulWidget>>? keyDefault, MainAxisAlignment? mainAxixIconLeft, CrossAxisAlignment? crossAxixIconLeft, double? heightIconLeft, double? widthIconLeft, Color? colorIconLeft, bool? isForceWarpUseExpanded, Gradient? gradient, bool? isVerified, MainAxisAlignment? mainAxixIconVerified, CrossAxisAlignment? crossAxixIconVerified, MainAxisSize? mainAxisSizeIconLeft})

Properties

alignment → Alignment?
final
border → Border?
final
borderRadius → BorderRadius?
final
boxShadow → List<BoxShadow>?
final
colorbackground → Color?
final
colorIconLeft → Color?
final
colorsText → Color?
final
crossAxixIconLeft → CrossAxisAlignment?
final
crossAxixIconVerified → CrossAxisAlignment?
final
fonts → String?
final
fontStyle → FontStyle?
final
fontWeight → FontWeight?
final
gradient → Gradient?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
heightIconLeft → double?
final
iconLeft → dynamic
final
isForceWarpUseExpanded → bool?
final
isGradient → bool?
final
final
isVerified → bool?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyDefault → GlobalKey<State<StatefulWidget>>?
final
mainAxisSizeIconLeft → MainAxisSize?
final
mainAxixIconLeft → MainAxisAlignment?
final
mainAxixIconVerified → MainAxisAlignment?
final
margin → EdgeInsets?
final
maxLines → int?
final
padding → EdgeInsets?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeText → double?
final
textAlign → TextAlign?
final
textDe → TextDecoration?
final
textLabel → String?
final
textOverflow → TextOverflow?
final
userTag → String?
final
userTagID → String?
final
width → double?
final
widthIconLeft → double?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _DefaultText
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited