TextSpanDefault class

Constructors

TextSpanDefault()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

geti(String text, {double? sizeFont, List<TextSpan>? childern, FontWeight? fontweight, Color? colorText, dynamic onTap2()?}) → TextSpan
getRed(String text) → TextSpan
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited