AddressVendorModel class

Constructors

AddressVendorModel({String? postcode, String? buildingNumber, String? streetName, String? buildingName, String? buildingCode, String? buildingDescription, String? longitude, String? latitude})
AddressVendorModel.fromJson(Map<String, dynamic> json)

Properties

buildingCode ↔ String?
getter/setter pair
buildingDescription ↔ String?
getter/setter pair
buildingName ↔ String?
getter/setter pair
buildingNumber ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
latitude ↔ String?
getter/setter pair
longitude ↔ String?
getter/setter pair
postcode ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streetName ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited