FirstLoginImage class

Constructors

FirstLoginImage({String? nationCode, String? id, String? device, String? url, String? priority, String? cdate, String? isActive})
FirstLoginImage.fromJson(Map<String, dynamic> json)

Properties

cdate ↔ String?
getter/setter pair
device ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
isActive ↔ String?
getter/setter pair
nationCode ↔ String?
getter/setter pair
priority ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited