GameShopModel class

Constructors

GameShopModel({String? balance, String? earnedTicket, List<ListTicketShop>? listTicketShop})
GameShopModel.fromJson(Map<String, dynamic> json)

Properties

balance ↔ String?
getter/setter pair
earnedTicket ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
listTicketShop ↔ List<ListTicketShop>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited